#----------------------------------------------------------------------------
#    SimSelect - Similarity-based Selection for 3D Surfaces
#
#    Authors : Emilie GUY, Jean-Marc THIERY and Tamy BOUBEKEUR
#
#    Copyright © 2012-2014 Telecom ParisTech - CNRS LTCI - Institut Mines Telecom
#        All rights reserved
#
# SimSelect is free software: you can redistribute it and/or modify
#
# it under the terms of the GNU Lesser General Public License as published by
#
# the Free Software Foundation, either version 3 of the License, or
#
# (at your option) any later version.
#
# SimSelect is distributed in the hope that it will be useful,
#
# but WITHOUT ANY WARRANTY; without even the implied warranty of
#
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
#
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#----------------------------------------------------------------------------

QT *= xml \
    opengl
QT += widgets

TARGET = simSelect
TEMPLATE = app

MOC_DIR = ./moc
OBJECTS_DIR = ./obj

INCLUDEPATH += .
INCLUDEPATH += ./include/
INCLUDEPATH += ./include/mesh
INCLUDEPATH += ./include/tools
INCLUDEPATH += ./include/selections
INCLUDEPATH += ./include/UI
INCLUDEPATH += ./src
INCLUDEPATH += ./src/mesh
INCLUDEPATH += ./src/tools
INCLUDEPATH += ./src/selections
INCLUDEPATH += ./src/UI
INCLUDEPATH += ./extern/
INCLUDEPATH += ./extern/ICP
INCLUDEPATH += ./extern/libsvm-3.17

CONFIG += qt \
    opengl \
    xml \
    warn_on \
    console \
    thread \
    release

HEADERS += \
    ./include/Shader.h \
    ./include/PhongShader.h \
    ./include/UI/GLViewer.h \
    ./include/UI/MainWindow.h \
    ./include/UI/QSmartColorPicker.h \
    ./include/UI/UserStroke.h \
    ./include/UI/SelectionWidget.h \
    ./include/UI/SelectionDock.h \
    ./include/UI/VisuDock.h \
    ./include/mesh/Vertex.h \
    ./include/mesh/Vec3D.h \
    ./include/mesh/Triangle.h \
    ./include/mesh/Mesh.h \
    ./include/mesh/Edge.h \
    ./include/mesh/MeshLaplacian.h \
    ./include/mesh/CotanLaplacian.h \
    ./include/tools/Debug.h \
    ./include/tools/GLUtilityMethods.h \
    ./include/tools/MathTools.h \
    ./include/tools/OpenGLHeader.h \
    ./include/tools/Distance.h \
    ./include/tools/Histogram2D.h \
    ./include/tools/CholmodStruct.h \
    ./include/tools/Histogram1D.h \
    ./include/tools/SVMclassification.h \
    ./include/selections/Selection.h \
    ./include/selections/SelectionsManager.h \
    ./include/selections/PatchSelection.h \
    ./include/selections/PartSelection.h \
    ./include/selections/CompSelection.h \
    ./extern/ICP/matrix.h \
    ./extern/ICP/kdtree.h \
    ./extern/ICP/icpPointToPoint.h \
    ./extern/ICP/icpPointToPlane.h \
    ./extern/ICP/icp.h

SOURCES += \
    ./src/Main.cpp \
    ./src/Shader.cpp \
    ./src/UI/MainWindow.cpp \
    ./src/UI/GLViewer.cpp \
    ./src/UI/UserStroke.cpp \
    ./src/UI/SelectionDock.cpp \
    ./src/UI/SelectionWidget.cpp \
    ./src/UI/VisuDock.cpp \
    ./src/mesh/Vertex.cpp \
    ./src/mesh/Triangle.cpp \
    ./src/mesh/Mesh.cpp \
    ./src/mesh/CotanLaplacian.cpp \
    ./src/tools/GLUtilityMethods.cpp \
    ./src/tools/MathTools.cpp \
    ./src/tools/SVMclassification.cpp \
    ./src/selections/SelectionsManager.cpp \
    ./src/selections/PatchSelection.cpp \
    ./src/selections/PartSelection.cpp \
    ./src/selections/CompSelection.cpp \
    extern/ICP/matrix.cpp \
    extern/ICP/kdtree.cpp \
    extern/ICP/icpPointToPoint.cpp \
    extern/ICP/icpPointToPlane.cpp \
    extern/ICP/icp.cpp \
    extern/libsvm-3.17/svm.cpp

DESTDIR = .
unix{
    BUILD_DIR =  /home/emilie/builds
    #-------------------------------------------------------------------------
    # change to set the path of your qglviewer directory
    #-------------------------------------------------------------------------
    INCLUDEPATH +=  $${BUILD_DIR}/libQGLViewer-2.5.0

    LIBS+= -lgsl \
    -lgslcblas \
    -lgomp \
    -lGLEW \
    -lGLU \
    -L$${BUILD_DIR}/libQGLViewer-2.5.0/QGLViewer \ # change to set the good path to your QGLViewer lib
    -lQGLViewer

    release:QMAKE_CXXFLAGS_RELEASE += -fopenmp
    release:QMAKE_CFLAGS_RELEASE += -fopenmp

    # ------------------------------ for CHOLMOD : ------------------------------#
    #-------------------------------------------------------------------------
    # the simple way to have cholmod is to install SuiteSparse
    #-------------------------------------------------------------------------
    INCLUDEPATH += $${BUILD_DIR}/SuiteSparse/CHOLMOD/Include \
        $${BUILD_DIR}/SuiteSparse/SuiteSparse_config

    LIBS += -lcholmod \
        -lsuitesparseconfig \
        -lamd \
        -lcolamd  \
        -lccolamd \
        -lcamd \
        -llapack \
        -lblas \
        -lgfortran \
        -lgfortranbegin \
        -lm
}

OTHER_FILES += \
    install.txt \
    readMe.txt
